"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[1438],{60274:function(a){function b(a){a.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}a.exports=b,b.displayName="arff",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_arff.a31ccbaace20667b.js.map