"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[81],{56267:function(a){function b(a){a.languages.properties={comment:/^[ \t]*[#!].*$/m,"attr-value":{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?: *[=:] *(?! )| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0},"attr-name":/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?= *[=:]| )/m,punctuation:/[=:]/}}a.exports=b,b.displayName="properties",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_properties.f2fb7a859f7aa876.js.map