#  This Source Code Form is subject to the terms of the Mozilla Public
#  License, v. 2.0. If a copy of the MPL was not distributed with this
#  file, You can obtain one at http://mozilla.org/MPL/2.0/.
#
#  Copyright 2024 FeatureForm Inc.
#

# For fetching sources as dataframes, the default limit is set to -1
# to denote that all records should be fetched.
NO_RECORD_LIMIT = -1

# 2 million records
TWO_MILLION_RECORD_LIMIT = 2_000_000
