"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[2221],{4137:function(a){function b(a){!function(a){for(var b=/"(?:\\.|[^\\"\r\n])*"|'(?:\\.|[^\\'\r\n])*'/.source,c=/\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))*\*\//.source,d=/(?:[^\\()[\]{}"'/]|<string>|\/(?![*/])|<comment>|\(<expr>*\)|\[<expr>*\]|\{<expr>*\}|\\[\s\S])/.source.replace(/<string>/g,function(){return b}).replace(/<comment>/g,function(){return c}),e=0;e<2;e++)d=d.replace(/<expr>/g,function(){return d});d=d.replace(/<expr>/g,"[^\\s\\S]"),a.languages.qml={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},"javascript-function":{pattern:RegExp(/((?:^|;)[ \t]*)function\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*\(<js>*\)\s*\{<js>*\}/.source.replace(/<js>/g,function(){return d}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:a.languages.javascript},"class-name":{pattern:/((?:^|[:;])[ \t]*)(?!\d)\w+(?=[ \t]*\{|[ \t]+on\b)/m,lookbehind:!0},property:[{pattern:/((?:^|[;{])[ \t]*)(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0},{pattern:/((?:^|[;{])[ \t]*)property[ \t]+(?!\d)\w+(?:\.\w+)*[ \t]+(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0,inside:{keyword:/^property/,property:/\w+(?:\.\w+)*/}}],"javascript-expression":{pattern:RegExp(/(:[ \t]*)(?![\s;}[])(?:(?!$|[;}])<js>)+/.source.replace(/<js>/g,function(){return d}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:a.languages.javascript},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},keyword:/\b(?:as|import|on)\b/,punctuation:/[{}[\]:;,]/}}(a)}a.exports=b,b.displayName="qml",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_qml.357b288a58cb1bfd.js.map