"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9770],{64385:function(a){function b(a){a.languages.processing=a.languages.extend("clike",{keyword:/\b(?:break|case|catch|class|continue|default|else|extends|final|for|if|implements|import|new|null|private|public|return|static|super|switch|this|try|void|while)\b/,function:/\b\w+(?=\s*\()/,operator:/<[<=]?|>[>=]?|&&?|\|\|?|[%?]|[!=+\-*\/]=?/}),a.languages.insertBefore("processing","number",{constant:/\b(?!XML\b)[A-Z][A-Z\d_]+\b/,type:{pattern:/\b(?:boolean|byte|char|color|double|float|int|[A-Z]\w*)\b/,alias:"class-name"}})}a.exports=b,b.displayName="processing",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_processing.da05782a706133f8.js.map