(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[5405],{75557:function(a,b,c){(window.__NEXT_P=window.__NEXT_P||[]).push(["/",function(){return c(53678)}])},53678:function(a,b,c){"use strict";c.r(b);var d=c(85893),e=c(9008),f=c.n(e);c(67294);var g=c(5813),h=function(){return(0,d.jsxs)("div",{children:[(0,d.jsx)(f(),{children:(0,d.jsx)("title",{children:"Featureform Dashboard"})}),(0,d.jsx)(g.Z,{})]})};b.default=h},9008:function(a,b,c){a.exports=c(5443)}},function(a){a.O(0,[9774,2888,179],function(){var b;return a(a.s=75557)}),_N_E=a.O()}])
//# sourceMappingURL=index-f45534c2dfd80b9f.js.map