"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[8614],{36500:function(a){function b(a){a.languages.ebnf={comment:/\(\*[\s\S]*?\*\)/,string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},special:{pattern:/\?[^?\r\n]*\?/,greedy:!0,alias:"class-name"},definition:{pattern:/^([\t ]*)[a-z]\w*(?:[ \t]+[a-z]\w*)*(?=\s*=)/im,lookbehind:!0,alias:["rule","keyword"]},rule:/\b[a-z]\w*(?:[ \t]+[a-z]\w*)*\b/i,punctuation:/\([:/]|[:/]\)|[.,;()[\]{}]/,operator:/[-=|*/!]/}}a.exports=b,b.displayName="ebnf",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_ebnf.2f33ed87c321c32b.js.map