self.__BUILD_MANIFEST={__rewrites:{beforeFiles:[],afterFiles:[],fallback:[]},"/":["static/chunks/pages/index-f45534c2dfd80b9f.js"],"/404":["static/chunks/pages/404-6ae1c67f55552cb1.js"],"/_error":["static/chunks/pages/_error-b04df28c0915943c.js"],"/query":["static/chunks/pages/query-469b79090675947c.js"],"/search":["static/chunks/pages/search-31b270dcde7e866f.js"],"/tasks":["static/chunks/pages/tasks-9132a1269c722610.js"],"/[type]":["static/chunks/pages/[type]-e3afb210feeb29cc.js"],"/[type]/[entity]":["static/chunks/pages/[type]/[entity]-a3aa972cb24daa01.js"],sortedPages:["/","/404","/_app","/_error","/query","/search","/tasks","/[type]","/[type]/[entity]"]},self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB()