"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[9389],{17766:function(a){function b(a){!function(a){function b(b,c){a.languages[b]&&a.languages.insertBefore(b,"comment",{"doc-comment":c})}var c=a.languages.markup.tag,d={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:c}};b("csharp",d),b("fsharp",d),b("vbnet",{pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:c}})}(a)}a.exports=b,b.displayName="xmlDoc",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_xmlDoc.c5ba5bb025e52250.js.map