"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4576],{12017:function(a){function b(a){var b;(b=a).languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},b.languages.gitignore=b.languages.ignore,b.languages.hgignore=b.languages.ignore,b.languages.npmignore=b.languages.ignore}a.exports=b,b.displayName="ignore",b.aliases=["gitignore","hgignore","npmignore"]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_ignore.78df395b5ef59118.js.map