"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[4045],{82707:function(a){function b(a){a.languages.prolog={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/(["'])(?:\1\1|\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1(?!\1)/,greedy:!0},builtin:/\b(?:fx|fy|xf[xy]?|yfx?)\b/,function:/\b[a-z]\w*(?:(?=\()|\/\d+)/,number:/\b\d+(?:\.\d*)?/,operator:/[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,punctuation:/[(){}\[\],]/}}a.exports=b,b.displayName="prolog",b.aliases=[]}}])
//# sourceMappingURL=react-syntax-highlighter_languages_refractor_prolog.50f489469e50d086.js.map